@@ -1,6 +1,6 @@
 from . import *
 
 from .callback import component
-from .subcomand import subcommand
+from .subcomand import base
 from .components import ActionRow, Button, SelectMenu, spread_to_rows
 from .setup import setup
